# cavespeak v0.1.1
A simple Python library to convert any given text into cavespeak!

---

## Table of Contents
- [Installation](#installation)
- [Usage](#usage)
- [Features](#features)

---

## Installation
Install cavespeak using pip:
```bash
pip install cavespeak
```

---

## Usage
Here are examples of how to use cavespeak:  

### Send a Basic Email!
Send a simple email with a subject and message:  
```python

```

---

## Features
- **Translate into cavespeak!**

---